import gettext
import re
import time
import gi
import os
import platform
import subprocess
import locale
import threading

from gi.repository import Gio, GLib, GObject


from locale import gettext as _
from pydbus import SystemBus

import PyQt6
from PyQt6 import QtWidgets, uic, QtGui
from PyQt6.QtCore import QTranslator
from PyQt6.QtWidgets import QMessageBox, QMainWindow, QInputDialog
from PyQt6.QtCore import pyqtSignal, QObject, Qt, QProcessEnvironment


bus = SystemBus()
the_dbus_starter = bus.get("org.redoswelcome.pydbus.Starter")
whoami = GLib.get_user_name()

from redoswelcomekde.pyqt_loading_progressbar import LoadingProgressBar
# from pyqt_loading_progressbar import LoadingProgressBar
class MyException(Exception):
    pass

JUST_STOP = False

def nongui(fun):
    """Decorator running the function in non-gui thread while
    processing the gui events."""
    from multiprocessing.pool import ThreadPool
    from PyQt6.QtWidgets import QApplication

    def wrap(*args, **kwargs):
        pool = ThreadPool(processes=1)
        async_ = pool.apply_async(fun, args, kwargs)
        while not async_.ready():
            async_.wait(0.01)
            QApplication.processEvents()
        return async_.get()
    return wrap

class RedosWelcomeDNF(QtWidgets.QDialog):
    report = str
    def __init__(self, rpm_path, ya_label, label_start_text, ya_button, parent=None):
        super().__init__(parent)
        # uic.loadUi('/home/wolandius/git_projects/redoswelcome-kde/data/ui/localinstall-dialog.ui', self)
        uic.loadUi('/usr/share/redos/redoswelcome/ui/localinstall-dialog.ui', self)
        self.rpm = " ".join(rpm for rpm in rpm_path)
        self.yandex_label = ya_label
        self.label_start_text = label_start_text
        self.button_yandex_browser = ya_button
        self.resolve_deps_local()
        self.deny_transaction_rpm.clicked.connect(self.close)
        self.accept_transaction_rpm.clicked.connect(self.on_accept_transaction_rpm_clicked)
        self.close_button.clicked.connect(self.close)
        progressBar = LoadingProgressBar()
        self.verticalLayout_3.addWidget(progressBar)

    """
    rpm_install_stack indexes:
    0 - dependenciesPage
    1 - progressPage
    2 - errorPage
    3 - successPage
    """

    def resolve_deps_local(self):
        global bus
        out = os.popen("systemctl is-active redoswelcome-dbus.service").readline().strip()
        if out == "inactive":
            the_dbus_starter.start()
        self.redos_dnf = bus.get("org.redoswelcome.pydbus.RedosWelcomeDNF", timeout=600)
        dependencies, errors = self.redos_dnf.dependencies_local_check(self.rpm).split("|||")
        if "r7-release" in self.rpm and len(self.rpm) > len("r7-release"):
            result = self.redos_dnf.dnf_command_gpg("r7-release", "/etc/pki/rpm-gpg/RPM-GPG-KEY-R7-OFFICE.public")
            self.rpm = re.sub("r7-release", "", self.rpm)
            if result == "0":
                self.resolve_extra_func()
            else:
                self.rpm_install_stack.set_visible_child_name("error_rpm_textview_page")
                self.error_rpm_textview.set_text(result)
        elif "yandex-browser-release" in self.rpm and len(self.rpm) > len("yandex-browser-release"):
            result = self.redos_dnf.dnf_command_gpg("yandex-browser-release", "")
            self.rpm = re.sub("yandex-browser-release", "", self.rpm)
            if result == "0":
                self.resolve_extra_func()
            else:
                self.rpm_install_stack.setCurrentIndex(2)
                self.error_rpm_textview.append(result)
        else:
            self.resolve_extra_func()
    def resolve_extra_func(self):
        dependencies, errors = self.redos_dnf.dependencies_local_check(self.rpm).split("|||")
        if "Операция отменена" in errors or "Operation aborted" in errors or "Операция прервана" in errors:
            dependencies = dependencies.split("\n")
            output = ""
            key = -1
            for i in range(0, len(dependencies)):
                if "=" in dependencies[i]:
                    key = i
                    break
            if key > -1:
                dependencies = dependencies[key + 1:]
            dependencies.remove('')
            for i in range(0, len(dependencies)):
                temp = dependencies[i].strip().split()
                if len(temp) > 5:
                    dependencies[i] = f'{temp[0]}-{temp[2]}.{temp[1]} {temp[3]} {temp[4]}{temp[5]}<br>'
                elif len(temp) == 5:
                    dependencies[i] = f'{temp[0]}-{temp[2]}.{temp[1]} {temp[3]} {temp[4]}<br>'
                elif len(temp) == 2 and (temp[0] == 'Результат' or temp[0] == 'Transaction'):
                    dependencies[i] = ""
                else:
                    dependencies[i] = f'<b>{dependencies[i]}</b><br>'
                output += f"{dependencies[i]}"
            self.rpm_install_stack.setCurrentIndex(0)
            self.resolve_dep_rpm_local.append(output)
        elif "Отсутствуют действия для выполнения" in dependencies:
            self.rpm_install_stack.setCurrentIndex(2)
            dependencies = dependencies.split("\n")
            output = ""
            key = -1
            for i in range(0, len(dependencies)):
                if "=" in dependencies[i]:
                    key = i
                    break
            if key > -1:
                dependencies = dependencies[key + 1:]
            for i in range(0, len(dependencies)):
                output += f"{dependencies[i]}\n"
            self.error_rpm_textview.append(output)
        else:
            self.rpm_install_stack.setCurrentIndex(2)
            self.error_rpm_textview.append(errors)
    # def close_dialog(self):
    #     if os.path.exists("/tmp/yandex-browser.rpm"):
    #         os.remove("/tmp/yandex-browser.rpm")
    #     self.close()

    def on_accept_transaction_rpm_clicked(self):
        global JUST_STOP #костыль, что бы кнопка рекурсивно сама себя не вызывала
        if not JUST_STOP:
            out = os.popen("systemctl is-active redoswelcome-dbus.service").readline().strip()
            if out == "inactive":
                the_dbus_starter.start()
            self.redos_dnf = bus.get("org.redoswelcome.pydbus.RedosWelcomeDNF", timeout=600)
            granted_access = self.redos_dnf.status_auth()
            if granted_access != "True":
                granted_access = self.redos_dnf.granteAuth(True)
            if granted_access == "rules granted":
                JUST_STOP = True
                self.rpm_install_stack.setCurrentIndex(1)
                result = self.local_install()
                if result[0] and result[1] == 0:
                    self.rpm_install_stack.setCurrentIndex(3)
                    #self.close()
            else:
                JUST_STOP = True
                self.rpm_install_stack.setCurrentIndex(2)
                self.error_rpm_textview.setText("Operation not granted")
                the_dbus_starter.stop()
    @nongui
    def local_install(self):
        result = self.redos_dnf.local_install(self.rpm)
        if result == "0":
            #os.system("dnf clean all && dnf makecache")
            the_dbus_starter.stop()
            return [True, 0]
        else:
            self.rpm_install_stack.setCurrentIndex(2)
            self.error_rpm_textview.setText(result)
            the_dbus_starter.stop()
            return [True, 1]

