#!/usr/bin/python3
import subprocess
import sys
import re
import os
import platform
import time

import gi
from gi.repository import Gio


import PyQt6
from PyQt6 import QtWidgets, uic, QtGui
from PyQt6.QtCore import QTranslator, QSize
from PyQt6.QtWidgets import QMessageBox, QMainWindow, QInputDialog
from PyQt6.QtCore import pyqtSignal, QObject, Qt, QProcessEnvironment

from redoswelcomekde.localinstall import RedosWelcomeDNF
from redoswelcomekde.common import AsyncWorker
#
# from localinstall import RedosWelcomeDNF
# from common import AsyncWorker

NORUN_FLAG = os.path.expanduser("~/.redoswelcome/norun.flag")


VERSION = "3.0"
class Window(QtWidgets.QMainWindow):
    def __init__(self, parent=None):
        super().__init__(parent)
        global appdir
        # uic.loadUi('/home/wolandius/git_projects/redoswelcome-kde/data/ui/redoswelcome-mainwindow.ui', self)
        uic.loadUi('/usr/share/redos/redoswelcome/ui/redoswelcome-mainwindow.ui', self)

        self.index = 0
        self.setWindowTitle(f"{self.windowTitle()} v{VERSION}")

        self.checkbox.setText(PyQt6.QtCore.QCoreApplication.translate('', "Show this dialog at startup"))
        if not os.path.exists(NORUN_FLAG):
            self.checkbox.setChecked(True)
        self.checkbox.toggled.connect(self.on_button_toggled)

        dist_name = PyQt6.QtCore.QCoreApplication.translate('',"RED OS")
        release = re.sub("Release:", "", os.popen("lsb_release -r").readline()).strip()
        if "n/a" in release:
            release = "8"
        elif "8.0" in release:
            release = "8"
        description = "standart" if "standard" in os.popen("lsb_release -d").readline().lower() else "certified"
        architecture = "64-bit"
        if platform.machine() != "x86_64":
            architecture = str(platform.machine())
        edition = "Unknown DE or in Root mode"
        if os.getenv("XDG_CURRENT_DESKTOP") == "X-Cinnamon" or os.getenv("XDG_CURRENT_DESKTOP") == "Cinnamon":
            edition = "Cinnamon"
        elif os.getenv("XDG_CURRENT_DESKTOP") == "MATE":
            edition = "Mate"
        elif os.getenv("XDG_CURRENT_DESKTOP") == "GNOME":
            edition = "GNOME"
        elif os.getenv("XDG_CURRENT_DESKTOP") == "KDE":
            edition = "KDE"

        icon = QtGui.QIcon.fromTheme("system-logo-icon")
        self.label_distrlogo.setPixmap(icon.pixmap(48, 48))

        self.label_softmanager_logo.setPixmap(QtGui.QIcon.fromTheme("dnfdragora").pixmap(48,48))
        self.label_softupd_logo.setPixmap(QtGui.QIcon.fromTheme("dnfdragora").pixmap(48,48))

        self.label_changes_logo.setPixmap(QtGui.QIcon.fromTheme("hwinfo").pixmap(48,48))
        self.label_about_logo.setPixmap(QtGui.QIcon.fromTheme("text-x-generic").pixmap(48,48))
        self.label_syssnap_logo.setPixmap(QtGui.QIcon.fromTheme("timeshift").pixmap(48,48))
        self.label_pref_apps_logo.setPixmap(QtGui.QIcon.fromTheme("preferences-desktop-default-applications").pixmap(48,48))
        self.label_task_mg_logo.setPixmap(QtGui.QIcon.fromTheme("utilities-system-monitor").pixmap(48,48))
        self.label_sys_settings_logo.setPixmap(QtGui.QIcon.fromTheme("gnome-control-center").pixmap(48,48))
        self.label_info_pc_logo.setPixmap(QtGui.QIcon.fromTheme("hwinfo").pixmap(48,48))
        self.label_network_logo.setPixmap(QtGui.QIcon.fromTheme("preferences-system-network").pixmap(48,48))
        self.label_join_domain_logo.setPixmap(QtGui.QIcon.fromTheme("preferences-system-network").pixmap(48,48))
        self.label_firewall_logo.setPixmap(QtGui.QIcon.fromTheme("preferences-system-firewall").pixmap(48,48))
        self.label_libre_logo.setPixmap(QtGui.QIcon.fromTheme("applications-office").pixmap(48,48))
        self.label_print_logo.setPixmap(QtGui.QIcon.fromTheme("printer").pixmap(48,48))

        self.label_version.setText("%s %s" % (dist_name, release))
        self.label_edition.setText("%s %s" % (edition, architecture))

        # Action buttons
        self.button_dnfdragora.clicked.connect(lambda: self.launch("dnfdragora"))
        self.button_dnfdragora_upd_all.clicked.connect(lambda: self.launch_args(["dnfdragora", "--update-only"]))
        self.button_timeshift.clicked.connect(lambda: self.launch("timeshift-launcher"))
        self.button_officeopen.clicked.connect( lambda: self.launch("libreoffice"))
        self.button_printers.clicked.connect(lambda: self.launch_args(["kde-add-printer", "--add-printer"]))
        self.button_network.clicked.connect( lambda: self.launch("nm-connection-editor"))
        self.button_taskmanager.clicked.connect( lambda: self.launch("plasma-systemmonitor"))
        self.button_settings.clicked.connect( lambda: self.launch("systemsettings"))
        self.button_firewall.clicked.connect(lambda: self.launch("firewall-config"))
        self.button_jointodomain.clicked.connect( lambda: self.launch_args(["pkexec", "join-to-domain.sh", "-g"]))
        self.button_prefered_apps.clicked.connect( lambda: self.launch_args(["systemsettings", "kcm_componentchooser"]))
        self.button_yandex_browser.clicked.connect(self.yandex)
        self.image_yandex_browser.setPixmap(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/yandex-browser.png").pixmap(48,48))
        self.image_r7_doceditors.setPixmap(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/р7-редактор.png").pixmap(48,48))
        self.image_r7_organizer.setPixmap(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/р7-органайзер.png").pixmap(48,48))
        self.image_r7_graphics.setPixmap(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/р7-графика.png").pixmap(48,48))
        self.button_r7_doceditors.clicked.connect(self.r7_doceditors)
        self.button_r7_organizer.clicked.connect(self.r7_organizer)
        self.button_r7_graphics.clicked.connect(self.r7_graphics)

        self.pushButton_welcome.clicked.connect(self.press_welcome)
        self.pushButton_sys.clicked.connect(self.press_sys_setup)
        self.third_party_apps.clicked.connect(self.press_third_party_apps)
        self.pushButton_doc.clicked.connect(self.press_doc)
        self.pushButton_about.clicked.connect(self.press_about)

        self.button_hardinfo.clicked.connect( lambda: self.launch("kinfocenter"))
        if os.getenv("XDG_CURRENT_DESKTOP") in ["Cinnamon", "X-Cinnamon"]:
            self.button_prefered_apps.clicked.connect( lambda: self.launch_args( ["cinnamon-settings", "default"]))
        elif os.getenv("XDG_CURRENT_DESKTOP") == "MATE":
            self.button_prefered_apps.clicked.connect( lambda: self.launch("mate-default-applications-properties"))
        elif os.getenv("XDG_CURRENT_DESKTOP") == "GNOME":
            self.button_prefered_apps.clicked.connect( lambda: self.launch("gnome-control-center"))

        # self.button_youtube.setIcon(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/youtube.png"))
        # self.button_youtube.setIconSize(QSize(32, 32))

        self.button_telegram.setIcon(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/telegram.png"))
        self.button_telegram.setIconSize(QSize(32, 32))

        self.button_vk.setIcon(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/vk.png"))
        self.button_vk.setIconSize(QSize(32, 32))

        self.button_ok.setIcon(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/ok.png"))
        self.button_ok.setIconSize(QSize(32, 32))

        self.button_rutube.setIcon(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/rutube.png"))
        self.button_rutube.setIconSize(QSize(32, 32))

        self.button_dzen.setIcon(QtGui.QIcon("/usr/share/redos/redoswelcome/ui/dzen.png"))
        self.button_dzen.setIconSize(QSize(32, 32))

        self.button_knowledgebase.clicked.connect(lambda: self.visit("https://redos.red-soft.ru/base"))
        self.button_documentation.clicked.connect(lambda: self.visit("https://redos.red-soft.ru/documentation/"))
        # self.button_youtube.clicked.connect(lambda: self.visit(
        #                                              "https://www.youtube.com/channel/UCjsj4-tf1n0pGpa-TLhl-YQ/featured"))
        self.button_telegram.clicked.connect(lambda: self.visit("https://t.me/redsoft1"))
        self.button_vk.clicked.connect(lambda: self.visit("https://vk.com/1redsoft"))
        self.button_ok.clicked.connect(lambda: self.visit("https://ok.ru/group/58410339270801"))
        self.button_rutube.clicked.connect(lambda: self.visit("https://rutube.ru/channel/23912197/"))
        self.button_dzen.clicked.connect(lambda: self.visit("https://zen.yandex.ru/id/622bab31563cdc2d9968ed7e"))

        self.button_aboutos.clicked.connect(lambda: self.visit("https://redos.red-soft.ru/"))
        self.button_redos_changelogs.clicked.connect(lambda:  self.visit(
                                        "https://redos.red-soft.ru/go/changelog/8-0-latest/")) if "standart" in description else \
            self.button_redos_changelogs.clicked.connect(lambda:  self.visit ("https://redos.red-soft.ru/go/changelog/8-0c-latest/"))
        self.button_rdb.clicked.connect(lambda: self.visit("https://reddatabase.ru/ru/"))
        self.button_redvirt.clicked.connect(lambda:self.visit (
                                                     "https://redos.red-soft.ru/product/red-virtualizatsiya/"))
        self.button_redadm.clicked.connect(lambda:  self.visit(
                                                    "https://redos.red-soft.ru/product/redadm/"))
        self.theme = None
        if edition == "Cinnamon":
            self.button_settings.clicked.connect(lambda: self.launch("cinnamon-settings"))
            self.theme = Gio.Settings(schema="org.cinnamon.desktop.interface").get_string("gtk-theme")
        elif edition == "Mate":
            self.button_settings.clicked.connect(lambda: self.launch("mate-control-center"))
            self.theme = Gio.Settings(schema="org.mate.interface").get_string("gtk-theme")
        elif edition == "GNOME":
            self.button_settings.clicked.connect(lambda: self.launch("gnome-control-center"))
            self.theme = Gio.Settings(schema="org.gnome.desktop.interface").get_string("gtk-theme")




        icon = QtGui.QIcon("/usr/share/redos/redoswelcome/ui/red-light.png")
        self.button_standart.setIcon(icon)
        self.button_standart.clicked.connect(self.on_button_standart_clicked)
        self.button_standart.setVisible(False)

        icon = QtGui.QIcon("/usr/share/redos/redoswelcome/ui/light.png")
        self.button_standart_kde.setIcon(icon)
        self.button_standart_kde.clicked.connect(self.on_button_standart_kde_clicked)

        icon = QtGui.QIcon("/usr/share/redos/redoswelcome/ui/aqua-light.png")
        self.button_alter.setIcon(icon)
        self.button_alter.clicked.connect(self.on_button_alter_clicked)
        self.button_alter.setVisible(False)

        icon = QtGui.QIcon("/usr/share/redos/redoswelcome/ui/aqua-dark.png")
        self.button_standart_dark.setIcon(icon)
        self.button_standart_dark.clicked.connect(self.on_button_standart_dark_clicked)
        self.button_standart_dark.setVisible(False)

        icon = QtGui.QIcon("/usr/share/redos/redoswelcome/ui/grey.png")
        self.button_standart_dark_kde.setIcon(icon)
        self.button_standart_dark_kde.clicked.connect(self.on_button_standart_dark_kde_clicked)

        icon = QtGui.QIcon("/usr/share/redos/redoswelcome/ui/red-dark.png")
        self.button_alter_dark.setIcon(icon)
        self.button_alter_dark.clicked.connect(self.on_button_alter_dark_clicked)
        self.button_alter_dark.setVisible(False)

    # def closeEvent(self, event):
    #     result = QtWidgets.QMessageBox.question(self,
    #                                         "Confirm Exit...",
    #                                         "Are you sure you want to exit ?",
    #                                         QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
    #     event.ignore()
    #
    #     if result == QtWidgets.QMessageBox.Yes:
    #         event.accept()

    def r7_doceditors(self):
        self.returncode = None
        self.label_start_text = PyQt6.QtCore.QCoreApplication.translate('',
            "Professional document, spreadsheet and presentation editors.")
        self.button_r7_doceditors.setEnabled(False)
        self.r7_doceditors_label.setText(PyQt6.QtCore.QCoreApplication.translate('', "Preparing for installation"))

        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_r7_doceditors,
            operation_inputs=inputs,
            operation_callback=self.start_r7_install
        )
        async_worker.start()

    def r7_graphics(self):
        self.returncode = None
        self.label_start_text = PyQt6.QtCore.QCoreApplication.translate('',
            "A tool for creating professional-grade diagrams, diagrams, graphs and business illustrations.")
        self.button_r7_graphics.setEnabled(False)
        self.r7_graphics_label.setText(PyQt6.QtCore.QCoreApplication.translate('',"Preparing for installation"))

        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_r7_graphics,
            operation_inputs=inputs,
            operation_callback=self.start_r7_install
        )
        async_worker.start()

    def r7_organizer(self):
        self.returncode = None
        self.label_start_text = PyQt6.QtCore.QCoreApplication.translate('',
            "Application for managing mail, contacts and business schedule.")
        self.button_r7_organizer.setEnabled(False)
        self.r7_organizer_label.setText(PyQt6.QtCore.QCoreApplication.translate('',"Preparing for installation"))
        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_r7_organizer,
            operation_inputs=inputs,
            operation_callback=self.start_r7_install
        )
        async_worker.start()

    def download_r7_doceditors(self, *inputs):
        check_install = os.popen("rpm -qa | grep r7-office").readlines()
        check_repo_file = os.popen("rpm -qa | grep r7-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                    return "allr7o"
            else:
                return "orelease"
        else:
            if len(check_install) == 0:
                return "r7o"
            else:
                self.r7_doceditors_label.setText(PyQt6.QtCore.QCoreApplication.translate('',"Package already installed"))
                return "1o"
    def download_r7_organizer(self, *inputs):
        check_install = os.popen("rpm -qa | grep r7organizer").readlines()
        check_repo_file = os.popen("rpm -qa | grep r7-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                    return "allr7org"
            else:
                return "orgrelease"
        else:
            if len(check_install) == 0:
                return "r7org"
            else:
                self.r7_organizer_label.setText(PyQt6.QtCore.QCoreApplication.translate('',"Rpm already installed"))
                return "1org"
    def download_r7_graphics(self, *inputs):
        check_install = os.popen("rpm -qa | grep R7Grafika").readlines()
        check_repo_file = os.popen("rpm -qa | grep r7-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                    return "allr7g"
            else:
                return "grelease"
        else:
            if len(check_install) == 0:
                return "r7g"
            else:
                self.r7_graphics_label.setText(PyQt6.QtCore.QCoreApplication.translate('',"Rpm already installed"))
                return "1g"

    def start_r7_install(self, worker, result, handler_data):
        """
        allr7o - means r7 repo +  r7-office
        allr7g - means r7 repo +  R7Grafika
        allr7org - means r7 repo +  r7organizer
        r7o - r7-office
        r7g - r7-R7Grafika
        r7org - r7organizer
        """
        result = worker.return_value(result)
        if result == "allr7o":
            win = RedosWelcomeDNF(["r7-office", "r7-release"], self.r7_doceditors_label, self.label_start_text, self.button_r7_doceditors, self)
            win.exec()
            self.r7_doceditors_label.setText(self.label_start_text)
            self.button_r7_doceditors.setEnabled(True)
        elif result == "allr7g":
            win = RedosWelcomeDNF(["R7Grafika", "r7-release"], self.r7_graphics_label, self.label_start_text, self.button_r7_graphics, self)
            win.exec()
            self.r7_graphics_label.setText(self.label_start_text)
            self.button_r7_graphics.setEnabled(True)
        elif result == "allr7org":
            win = RedosWelcomeDNF(["r7organizer", "r7-release"], self.r7_organizer_label, self.label_start_text, self.button_r7_organizer, self)
            win.exec()
            self.r7_organizer_label.setText(self.label_start_text)
            self.button_r7_organizer.setEnabled(True)
        elif result == "orelease":
            win = RedosWelcomeDNF(["r7-release"], self.r7_doceditors_label, self.label_start_text, self.button_r7_doceditors, self)
            win.exec()
            self.r7_doceditors_label.setText(self.label_start_text)
            self.button_r7_doceditors.setEnabled(True)
        elif result == "orgrelease":
            win = RedosWelcomeDNF(["r7-release"], self.r7_organizer_label, self.label_start_text, self.button_r7_organizer, self)
            win.exec()
            self.r7_organizer_label.setText(self.label_start_text)
            self.button_r7_organizer.setEnabled(True)
        elif result == "grelease":
            win = RedosWelcomeDNF(["r7-release"], self.r7_graphics_label, self.label_start_text, self.button_r7_graphics, self)
            win.exec()
            self.r7_graphics_label.setText(self.label_start_text)
            self.button_r7_graphics.setEnabled(True)
        elif result == "r7o":
            win = RedosWelcomeDNF(["r7-office"], self.r7_doceditors_label, self.label_start_text, self.button_r7_doceditors, self)
            win.exec()
            self.r7_doceditors_label.setText(self.label_start_text)
            self.button_r7_doceditors.setEnabled(True)
        elif result == "r7g":
            win = RedosWelcomeDNF(["R7Grafika"], self.r7_graphics_label, self.label_start_text, self.button_r7_graphics, self)
            win.exec()
            self.r7_graphics_label.setText(self.label_start_text)
            self.button_r7_graphics.setEnabled(True)
        elif result == "r7org":
            win = RedosWelcomeDNF(["r7organizer"], self.r7_organizer_label, self.label_start_text, self.button_r7_organizer, self)
            win.exec()
            self.r7_organizer_label.setText(self.label_start_text)
            self.button_r7_organizer.setEnabled(True)
        elif result == "1o":
            time.sleep(3)
            self.r7_doceditors_label.setText(self.label_start_text)
            self.button_r7_doceditors.setEnabled(True)
        elif result == "1org":
            time.sleep(3)
            self.r7_organizer_label.setText(self.label_start_text)
            self.button_r7_organizer.setEnabled(True)
        elif result == "1g":
            time.sleep(3)
            self.r7_graphics_label.setText(self.label_start_text)
            self.button_r7_graphics.setEnabled(True)

    def on_button_toggled(self, button):
        if self.checkbox.isChecked():
            if os.path.exists(NORUN_FLAG):
                os.system("rm -rf %s" % NORUN_FLAG)
        else:
            os.system("mkdir -p ~/.redoswelcome")
            os.system("touch %s" % NORUN_FLAG)

    def visit(self, url):
        subprocess.Popen(["xdg-open", url])

    def on_button_standart_clicked(self):
        theme = "RedOS-Red"
        wm_theme = "RedOS-Red"
        icons_theme = "RedOS"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_standart_kde_clicked(self):
        #theme = "redos.kde.theme.RedOS-light"
        theme = "com.kde.theme.RedOS-Light"
        self.call_change_theme_kde(theme)

    def on_button_standart_dark_kde_clicked(self):
        #theme = "redos.kde.theme.RedOS-dark"
        theme = "com.kde.theme.RedOS-Dark"
        self.call_change_theme_kde(theme)
    #
    def on_button_alter_clicked(self):
        theme = "RedOS-Blue"
        wm_theme = "RedOS-Blue"
        icons_theme = "RedOS-Alternative"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_standart_dark_clicked(self):
        theme = "RedOS-Red-Dark"
        wm_theme = "RedOS-Red-Dark"
        icons_theme = "RedOS-Dark"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_alter_dark_clicked(self):
        theme = "RedOS-Blue-Dark"
        wm_theme = "RedOS-Blue-Dark"
        icons_theme = "RedOS-Alternative-Dark"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def call_change_theme_kde(self, theme):
        os.system(f"lookandfeeltool -a {theme}")
        #os.system("kill -9 $(ps aux | grep '[p]lasmashell' | awk '{print $2}')")

    def call_change_theme(self, theme, icons_theme, wm_theme, cinnamon_theme):
        if os.getenv("XDG_CURRENT_DESKTOP") in ["Cinnamon", "X-Cinnamon"]:
            settings = Gio.Settings(schema="org.cinnamon.desktop.interface")
            settings.set_string("gtk-theme", theme)
            settings.set_string("icon-theme", icons_theme)
            Gio.Settings(schema="org.cinnamon.desktop.wm.preferences").set_string("theme", wm_theme)
            Gio.Settings(schema="org.cinnamon.theme").set_string("name", cinnamon_theme)

        elif os.getenv("XDG_CURRENT_DESKTOP") == "MATE":
            settings = Gio.Settings(schema="org.mate.interface")
            settings.set_string("gtk-theme", theme)
            settings.set_string("icon-theme", icons_theme)
            Gio.Settings(schema="org.mate.Marco.general").set_string("theme", wm_theme)

        elif os.getenv("XDG_CURRENT_DESKTOP") == "GNOME":
            settings = Gio.Settings(schema="org.gnome.desktop.interface")
            settings.set_string("gtk-theme", theme)
            settings.set_string("icon-theme", icons_theme)
            Gio.Settings(schema="org.gnome.metacity.theme").set_string("name", wm_theme)
        # todo: work with schemas on KDE, XFCE
    def press_welcome(self):
        self.index = 0
        self.change_index()

    def press_sys_setup(self):
        self.index = 1
        self.change_index()

    def press_doc(self):
        self.index = 3
        self.change_index()

    def press_third_party_apps(self):
        self.index = 2
        self.change_index()
    def press_about(self):
        self.index = 4
        self.change_index()

    def change_index(self):
        self.main_stack.setCurrentIndex(self.index)

    def launch(self, command):
        if "dnfdragora" in command:
            self.kill_dnfdragora()
        subprocess.Popen(command)

    def launch_args(self, command):
        for arg in command:
            if "dnfdragora" in arg:
                self.kill_dnfdragora()
                break
        subprocess.Popen(command)

    def pkexec(self, command):
        subprocess.Popen(["pkexec", command])

    def kill_dnfdragora(self):
        os.system("kill -9 $(ps aux | grep '[d]nfdragora --\|[d]nfdragora$' | awk '{print $2}')")


    def yandex(self):
        #self.returncode = None
        self.label_start_text = PyQt6.QtCore.QCoreApplication.translate('', "Install Yandex.Browser, a safe and fast Russian browser that supports TLS protocols according to GOST. It automatically translates videos, stores your passwords securely, and protects against viruses and scammers.")
        self.button_yandex_browser.setEnabled(False)
        self.yandex_label.setText(PyQt6.QtCore.QCoreApplication.translate('',"Preparing for installation"))
        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_yandex,
            operation_inputs=inputs,
            operation_callback=self.start_yandex_install
        )
        async_worker.start()

    def download_yandex(self, *inputs):
        check_install = os.popen("rpm -qa | grep yandex-browser-stable").readlines()
        check_repo_file = os.popen("rpm -qa | grep yandex-browser-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                return "ya-all"
            else:
                return "ya-release"
        else:
            if len(check_install) == 0:
                return "ya-browser"
            else:
                self.yandex_label.setText(PyQt6.QtCore.QCoreApplication.translate('', "Rpm already installed"))
                return 1

    def start_yandex_install(self, worker, result, handler_data):
        result = worker.return_value(result)
        if result == "ya-all":
            win = RedosWelcomeDNF(rpm_path=["yandex-browser-stable", "yandex-browser-release"], ya_label=self.yandex_label, label_start_text=self.label_start_text, ya_button=self.button_yandex_browser, parent=self)
            win.exec()
            self.yandex_label.setText(self.label_start_text)
            self.button_yandex_browser.setEnabled(True)
        elif result == "ya-release":
            win = RedosWelcomeDNF(["yandex-browser-release"], self.yandex_label, self.label_start_text, self.button_yandex_browser, self)
            win.exec()
            self.yandex_label.setText(self.label_start_text)
            self.button_yandex_browser.setEnabled(True)
        elif result == "ya-browser":
            win = RedosWelcomeDNF(["yandex-browser-stable"], self.yandex_label, self.label_start_text, self.button_yandex_browser, self)
            win.exec()
            self.yandex_label.setText(self.label_start_text)
            self.button_yandex_browser.setEnabled(True)
        elif result == 1:
            time.sleep(3)
            self.yandex_label.setText(self.label_start_text)
            self.button_yandex_browser.setEnabled(True)
