#!/usr/bin/python3
import os
import re
import subprocess
import sys
import time

import dbus
from pydbus import SystemBus
from gi.repository import GLib

loop = GLib.MainLoop()


class MyException(Exception):
    pass

class TestObject(object):
    dbus = '''
    <node>
        <interface name='org.redoswelcome.pydbus.RedosWelcomeDNF'>
            <method name='granteAuth'>
                <arg type='b' name='interactive' direction='in'/>
                <arg type='s' name='response' direction='out'/>
            </method>
            <method name='local_install'>
                <arg type='s' name='rpm_path' direction='in'/>
                <arg type='s' name='response' direction='out'/>
            </method>
            <method name='dnf_command_gpg'>
                <arg type='s' name='repo' direction='in'/>
                <arg type='s' name='gpg_path' direction='in'/>
                <arg type='s' name='response' direction='out'/>
            </method>
            <method name='status_auth'>
                <arg type='s' name='enable' direction='out'/>
            </method>
            <method name='dependencies_local_check'>
                <arg type='s' name='rpm_path' direction='in'/>
                <arg type='s' name='response' direction='out'/>
            </method>
        </interface>
    </node>
    '''

    def granteAuth(self, interactive,
                   dbus_context):
        if dbus_context.is_authorized('org.freedesktop.policykit.exec', {'polkit.icon': '/usr/share/icons/RedOS/16/places/start-here-red.svg', 'aaaa': 'zzzz'},
                                      interactive=interactive):
            global rules_granted
            self.rules_granted = True
            return "rules granted"
        else:
            self.rules_granted = False
            return "rules not granted"



    def status_auth(self):
        if hasattr(self, 'rules_granted'):
            if self.rules_granted:
                return "True"
            else:
                return "False"
        else:
            return "False"

    def local_install(self, rpm_path):
        if self.rules_granted:
            spec = rpm_path
            return self.dnf_command("install", spec)
        else:
            return "rules not granted"

    def dependencies_local_check(self, rpm_path):
        return self.dnf_resolvedep("install", rpm_path)

    def dnf_resolvedep(self, command, spec):
        dnf_out = subprocess.Popen([f'/usr/bin/dnf {command} --assumeno {spec}'],
                               stdout=subprocess.PIPE,
                               stderr=subprocess.PIPE, shell=True)
        output, error = dnf_out.communicate()
        output = output.decode('utf-8').split('\n')
        if len(output) > 11:
            output = output[4:] if command == 'remove' else \
                output[5:]
            output = output[:len(output) - 7]
        out = ""
        for o in output:
            out += f"{o}\n"
        return f"{out}|||{error.decode('utf-8')}"

    def dnf_command(self, command, spec):
        if spec != "":
            dnf_out = subprocess.Popen([f'/usr/bin/dnf {command} -y {spec}'],
                                       stdout=subprocess.PIPE,
                                       stderr=subprocess.PIPE, shell=True)
        else:
            dnf_out = subprocess.Popen(['/usr/bin/dnf', command, '-y'],
                                       stdout=subprocess.PIPE,
                                       stderr=subprocess.PIPE)
        output, error = dnf_out.communicate()
        if dnf_out.returncode != 0:
            return f"{error.decode('utf-8')}"
        else:
            return "0"

    def dnf_command_gpg(self, repo, gpg_path):
        """
        silent installer for repo files
        """
        dnf_out = subprocess.Popen([f'/usr/bin/dnf install -y {repo}'],
                                   stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE, shell=True)

        output, error = dnf_out.communicate()
        if dnf_out.returncode == 0:
            if len(gpg_path) > 0:
                dnf_out = subprocess.Popen([f'rpm --import {gpg_path}'],
                                               stdout=subprocess.PIPE,
                                               stderr=subprocess.PIPE, shell=True)
                output, error = dnf_out.communicate()
            if dnf_out.returncode != 0:
                return f"{error.decode('utf-8')}"
            else:
                return "0"
        else:
            return f"{error.decode('utf-8')}"

    def dnf_repo_command(self, command, spec, repo):
        if spec != "":
            dnf_out = subprocess.Popen([f'/usr/bin/dnf {command} -y {spec} --enablerepo '],
                                       stdout=subprocess.PIPE,
                                       stderr=subprocess.PIPE, shell=True)
        else:
            dnf_out = subprocess.Popen(['/usr/bin/dnf', command, '-y'],
                                       stdout=subprocess.PIPE,
                                       stderr=subprocess.PIPE)
        output, error = dnf_out.communicate()
        if dnf_out.returncode != 0:
            return f"{error.decode('utf-8')}"
        else:
            return "0"

    def quit(self):
        """removes this object from the DBUS connection and exits"""
        loop.quit()


if __name__ == "__main__":
    if len(sys.argv) == 1:
        with SystemBus() as bus:
            with bus.publish("org.redoswelcome.pydbus.RedosWelcomeDNF", TestObject()):
                loop.run()
    elif len(sys.argv) > 1:
        if sys.argv[1] == "--start":
            with SystemBus() as bus:
                with bus.publish("org.redoswelcome.pydbus.RedosWelcomeDNF", TestObject()):
                    loop.run()
        elif sys.argv[1] == "--stop":
            loop.quit()
